list_ = [
    r"gold(?:en)?",
    "dark",
    "hearty",
    "rich",
    "homemade",
    "tasty",
    "delicious",
    "yummy",
    "good",
    "cheap",
    "expensive",
    "entire",
    "leftover",
    "quick",
    "easy",
    "simple",
    "fine",
    r"\w+[- ]?sodium",
    "creamy",
    "organic",
    "broken",
    "all-butter",
    "sweet",
    "mild",
    "sharp",
    "firm",
    "soft",
    "aged",
    "thin",
    "thick",
    "lean",
    "stoneground",
    r"\w+[- ]?style",
    r"(?:[0-9]+ [0-9]+/[0-9]+|[0-9]+)[- ]?inch(?:[ -]thick)?",
    r"\w+-sodium",
    r"\w+-fat",
    r"free[- ]range",
    "whole",
    "skin-on",
    "hot",
    "cold",
    "warm",
    "boiling",
    r"\b(?<!\.)(?!0+(?:\.0+)?[ -]?%)(?:\d|[1-9]\d|100)(?:(?<!100)\.\d+)?[ -]?%",
    r"fresh(?:ly)?",
    r"[0-9]+[- ]bone",
    "quality",
    "chopped",
    "ground",
    "sliced",
    "minced",
    "cut",
    "diced",
    "peeled",
    "grated",
    "shredded",
    "drained",
    "dry",
    "coarse",
    "crushed",
    "crusted",
    "dried",
    "cooked",
    "boneless",
    "seeded",
    "beaten",
    "skinless",
    "unsalted",
    "cubed",
    "rinsed",
    "melted",
    "softened",
    "canned",
    "toasted",
    "crumbled",
    "quartered",
    "uncooked",
    "roasted",
    "trimmed",
    "pitted",
    "thawed",
    "granulated",
    "frozen",
    "washed",
    "ripe",
    "mixed",
    "powdered",
    "cored",
    "unsweetened",
    "condensed",
    "smoked",
    "deveined",
    "reduced",
    "mashed",
    "halved",
    "separated",
    "boiled",
    "raw",
    "undrained",
    "seasoned",
    "sifted",
    "slivered",
    "juiced",
    "squeezed",
    "sweetened",
    "evaporated",
    "whipped",
    "blanched",
    "chilled",
    "julienned",
    "cracked",
    "prepared",
    "shelled",
    "stemmed",
    "refried",
    "stewed",
    "unbleached",
    "flaked",
    "skinned",
    "flavored",
    "refrigerated",
    "semisweet",
    "unpeeled",
    "smashed",
    "salted",
    "pickled",
    "packed",
    "snipped",
    "seedless",
    "bottled",
    "deseeded",
    "soaked",
    "rolled",
    "cooled",
    "candied",
    "warmed",
    "baked",
    "scrubbed",
    "steamed",
    "distilled",
    "pressed",
    "corned",
    "marinated",
    "brewed",
    "undiluted",
    "shaved",
    "clarified",
    "stuffed",
    "pureed",
    "unflavored",
    "desiccated",
    "creamed",
    "grilled",
    "zested",
    "hulled",
    "substituted",
    "defrosted",
    "unbaked",
    "assorted",
    "heated",
    "husked",
    "preserved",
    "strained",
    "browned",
    "scraped",
    "thickened",
    "processed",
    "cleaned",
    "jarred",
    "bruised",
    "unseasoned",
    "chunked",
    "crystallized",
    "scalded",
    "rubbed",
    "precooked",
    "buttered",
    "carbonated",
    "stoned",
    "sauteed",
    "tied",
    "shucked",
    "unsifted",
    "butterflied",
    "bone-in",
    "colored",
    "debearded",
    "cured",
    "spiced",
    "spicy",
    "converted",
    "imported",
    "seperated",
    "tinned",
    "blended",
    "added",
    "whisked",
    "deboned",
    "hardboiled",
    "shaped",
    "purchased",
    "fermented",
    "sectioned",
    "veined",
    "suggested",
    "unsliced",
    "pounded",
    "ripened",
    "parboiled",
    "packaged",
    "sorted",
    "textured",
    "dehydrated",
    "grounded",
    "refined",
    "filtered",
    "poached",
    "chipped",
    "compressed",
    "segmented",
    "sieved",
    "heaped",
    "jointed",
    "flattened",
    "combined",
    "unrefined",
    "gutted",
    "caramelized",
    "sprinkled",
    "scaled",
    "pulled",
    "desired",
    "based",
    "rendered",
    "tailed",
    "unblanched",
    "brushed",
    "stripped",
    "diluted",
    "stirred",
    "homogenized",
    "barbecued",
    "concentrated",
    "wedged",
    "herbed",
    "rehydrated",
    "breaded",
    "deviened",
    "scored",
    "rounded",
    "wiped",
    "posted",
    "defatted",
    "filleted",
    "frenched",
    "skin-on",
    "unwaxed",
    "reconstituted",
    "tossed",
    "flavoured",
    "unshelled",
    "choped",
    "tenderized",
    "charred",
    "pasteurized",
    "malted",
    "unsmoked",
    "filled",
]